/*
 * unity-webapps-dirs.c
 * Copyright (C) Canonical LTD 2011
 *
 * Author: Robert Carr <racarr@canonical.com>
 * 
 unity-webapps is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * unity-webapps is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 */

#include <sys/stat.h>
#include <errno.h>

#include <glib/gstdio.h>

#include "unity-webapps-dirs.h"

/*
 * Get the unity webapps user storage directory (and ensure it exists).
 * Currently this is $HOME/.local/share/unity-webapps
 */

gchar *
unity_webapps_dirs_get_user_dir ()
{
  const gchar *homedir;
  gchar *userdir;
  
  homedir = g_getenv ("HOME");
  if (!homedir)
    homedir = g_get_home_dir ();
  
  userdir = g_build_filename(homedir, ".local", "share", "unity-webapps", NULL);
  
  if (g_file_test (userdir, G_FILE_TEST_EXISTS) == FALSE)
    {
      int status;

      status = g_mkdir (userdir, 0700);
      
      if (status < -1)
	{
	  g_critical ("Error making Unity Webapps user dir (%s): %s", userdir, g_strerror(errno));
	  
	  g_free (userdir);
	  
	  return NULL;
	}
    }
  
  return userdir;  
}

/*
 * Get the unity webapps icon storage directory and ensure it exists, 
 * currently this is a folder "icons" inside the user storage directory. */
gchar *
unity_webapps_dirs_get_icon_dir () 
{
  gchar *userdir, *icondir;
  
  userdir = unity_webapps_dirs_get_user_dir ();

  icondir = g_build_filename (userdir, "icons", NULL);
  
  if (g_file_test (icondir, G_FILE_TEST_EXISTS) == FALSE)
    {
      int status; 

      status = g_mkdir (icondir, 0700);
      
      if (status < -1)
	{
	  g_critical ("Error making Unity Webapps icon dir (%s): %s", icondir, g_strerror(errno));
	  
	  g_free (icondir);
	  
	  return NULL;
	}
    }
  
  g_free (userdir);
  
  return icondir;
}


