/*
 * unity-webapps-indicator-context.c
 * Copyright (C) Canonical LTD 2011
 *
 * Author: Robert Carr <racarr@canonical.com>
 * 
 unity-webapps is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * unity-webapps is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 */

#include <stdio.h>

#include "unity-webapps-indicator-context.h"

UnityWebappsIndicatorContext *
unity_webapps_indicator_context_new (GDBusConnection *connection, const gchar *name)
{
  GError *error = NULL;
  UnityWebappsIndicatorContext *context;
  
  g_return_val_if_fail (connection != NULL, NULL);
  
  context = g_malloc0 (sizeof (UnityWebappsIndicatorContext));
  
  context->indicator_proxy = 
    unity_webapps_gen_indicator_proxy_new_sync (connection ,
						G_DBUS_PROXY_FLAGS_NONE,
						name,
						UNITY_WEBAPPS_INDICATOR_PATH, 
						NULL /* Cancellable */,
						&error);
  
  if (error != NULL)
    {
      g_critical ("Error creating indicator context proxy object for %s: %s", name, error->message);
      
      g_error_free (error);
      
      return NULL;
    }
  
  return context;
}

void 
unity_webapps_indicator_context_free (UnityWebappsIndicatorContext *context)
{
  g_object_unref (G_OBJECT (context->indicator_proxy));
  
  g_free (context);
}



void
unity_webapps_indicator_show_indicator (UnityWebappsContext *context,
					const gchar *name)
{
  GError *error;
  
  error = NULL;
  
  unity_webapps_gen_indicator_call_show_indicator_sync (context->indicator_context->indicator_proxy,
							name,
							NULL /* Cancellable */,
							&error);
  
  if (error)
    {
      g_critical ("Error invoking proxy method in unity_webapps_indicator_show_indicator: %s",
		  error->message);
      g_error_free (error);
      
      return;
    }
}

void
unity_webapps_indicator_clear_indicator (UnityWebappsContext *context,
					 const gchar *name)
{
  GError *error;
  
  error = NULL;
  
  unity_webapps_gen_indicator_call_clear_indicator_sync (context->indicator_context->indicator_proxy,
							 name,
							 NULL /* Cancellable */,
							 &error);
  
  if (error)
    {
      g_critical ("Error invoking proxy method in unity_webapps_indicator_clear_indicator: %s",
		  error->message);
      g_error_free (error);
      
      return;
    }
}

void 
unity_webapps_indicator_set_property (UnityWebappsContext *context, 
				      const gchar *name, 
				      const gchar *property, 
				      const gchar *value)
{
  GError *error;
  
  error = NULL;
  
  unity_webapps_gen_indicator_call_set_property_sync (context->indicator_context->indicator_proxy,
						      name,
						      property,
						      value,
						      NULL /* Cancellable */,
						      &error);
  
  if (error)
    {
      g_critical ("Error invoking proxy method in unity_webapps_indicator_set_property: %s",
		  error->message);
      g_error_free (error);
      
      return;
    }
}


