/*
 * unity-webapps-notification-context.c
 * Copyright (C) Canonical LTD 2011
 *
 * Author: Robert Carr <racarr@canonical.com>
 * 
 unity-webapps is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * unity-webapps is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 */

#include <stdio.h>

#include "unity-webapps-notification-context.h"

UnityWebappsNotificationContext *
unity_webapps_notification_context_new (GDBusConnection *connection, const gchar *name)
{
  GError *error = NULL;
  UnityWebappsNotificationContext *context;
  
  g_return_val_if_fail (connection != NULL, NULL);
  
  context = g_malloc0 (sizeof (UnityWebappsNotificationContext));
  
  context->notification_proxy = 
    unity_webapps_gen_notification_proxy_new_sync (connection ,
						   G_DBUS_PROXY_FLAGS_NONE,
						   name,
						   UNITY_WEBAPPS_NOTIFICATION_PATH, 
						   NULL /* Cancellable */,
						   &error);
  
  if (error != NULL)
    {
      g_critical ("Error creating notification context proxy object for %s: %s", name, error->message);
      
      g_error_free (error);
      
      return NULL;
    }
  
  return context;
}

void 
unity_webapps_notification_context_free (UnityWebappsNotificationContext *context)
{
  g_object_unref (G_OBJECT (context->notification_proxy));
  
  g_free (context);
}



void
unity_webapps_notification_show_notification (UnityWebappsContext *context,
					      const gchar *summary,
					      const gchar *body,
					      const gchar *icon_url)
{
  GError *error;
  
  error = NULL;
  
  unity_webapps_gen_notification_call_show_notification_sync (context->notification_context->notification_proxy,
							      summary,
							      body,
							      icon_url ? icon_url : "",
							      NULL /* Cancellable */,
							      &error);
  
  if (error)
    {
      g_critical ("Error invoking proxy method in unity_webapps_notification_show_notification: %s",
		  error->message);
      g_error_free (error);
      
      return;
    }
}
