/*
 * unity-webapps-service.c
 * Copyright (C) Canonical LTD 2011
 *
 * Author: Robert Carr <racarr@canonical.com>
 * 
 unity-webapps is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * unity-webapps is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.";
 */

#include <stdio.h>

#include "unity-webapps-service.h"


UnityWebappsService *
unity_webapps_init ()
{
  GError *error;
  UnityWebappsService *service;

  error = NULL;
  
  service = g_malloc0 (sizeof (UnityWebappsService));
  
  service->session_bus = g_bus_get_sync (G_BUS_TYPE_SESSION,
					 NULL /*Cancellable*/,
					 &error /*Error*/);
  
  if (error != NULL)
    {
      g_critical ("Failed to open session bus! %s", error->message);

      g_error_free (error);
      return NULL;
    }
  
  service->service_proxy = unity_webapps_gen_service_proxy_new_sync (service->session_bus,
									     G_DBUS_PROXY_FLAGS_NONE,
									     UNITY_WEBAPPS_SERVICE_NAME,
									     UNITY_WEBAPPS_SERVICE_PATH,
									     NULL,
									     &error);
  
  if (error != NULL)
    {
      g_critical ("Failed to create service proxy. %s", error->message);
      g_error_free (error);
      
      return NULL;
    }
  
  return service;
}
