#include <stdlib.h>

#include "../src/unity-webapps-service.h"
#include "../src/unity-webapps-context.h"

static void
test_context_simple_create ()
{
  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
    {
      UnityWebappsService *service;
      UnityWebappsContext *context;

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      g_assert (context != NULL);
      g_printf("Created context", NULL);
      
      exit(0);
    }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Created context");
}

static void
test_context_create_2 ()
{
  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
    {
      UnityWebappsService *service;
      UnityWebappsContext *context;

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      g_assert (context != NULL);
      g_printf("Created context");
      
      unity_webapps_context_free (context);
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      unity_webapps_context_free (context);
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      exit(0);
    }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Created context");
}

static void
test_context_properties()
{
  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
    {
      UnityWebappsService *service;
      UnityWebappsContext *context;

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      g_assert (g_strcmp0("Test", unity_webapps_context_get_name(context)) == 0);
      g_assert (g_strcmp0("test.ts", unity_webapps_context_get_domain(context)) ==0);
      
      printf("Verified properties");
      
      exit(0);
    }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Verified properties");
}

int 
main (int argc, char **argv)
{
  g_thread_init (NULL);
  g_type_init ();
  g_test_init (&argc, &argv, NULL);
  
  g_test_add_func("/context/simple-create",
		  test_context_simple_create);
  g_test_add_func("/context/create-2",
		  test_context_create_2);
  g_test_add_func("/context/properties",
		  test_context_properties);
  
  return g_test_run ();
}

