#include <stdlib.h>

#include "../src/unity-webapps-service.h"
#include "../src/unity-webapps-context.h"

int num_callbacks = 0;

static void
on_raise ()
{
  printf("Raise\n", NULL);
  num_callbacks ++;
  
  if (num_callbacks == 3)
    exit(0);
}

static void
on_play_pause ()
{
  printf("PlayPause", NULL);
  num_callbacks ++;
  
  if (num_callbacks == 3)
    exit(0);
}

static void
on_next ()
{
  printf("Next", NULL);
  num_callbacks ++;
  
  if (num_callbacks == 3)
    exit(0);
}

static void
on_previous()
{
  printf("Previous", NULL);
  num_callbacks ++;
  
  if (num_callbacks == 4)
    exit(0);
}

static void
test_music_player_init ()
{
  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;
      
      g_thread_init (NULL);
      
      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_music_player_init (context, "Test player");
      g_printf("Showed music player", NULL);
      
      exit(0);
      }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Showed music player");
}

static void
test_music_player_set_track ()
{
    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;
      
      g_thread_init (NULL);

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_music_player_init (context, "Test player");
      unity_webapps_music_player_set_track (context, "Test artist",
					    "Test album",
					    "Test title",
					    NULL);
      g_printf("Set track", NULL);
      
            exit(0);
      }
        g_test_trap_assert_passed();
        g_test_trap_assert_stdout ("Set track");
}

static void
test_music_player_callbacks ()
{
  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;
      
      g_thread_init (NULL);

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_music_player_init (context, "Test player");
      unity_webapps_music_player_on_raise_callback (context, on_raise);
      unity_webapps_music_player_on_play_pause_callback (context, on_play_pause);
      unity_webapps_music_player_on_previous_callback (context, on_previous);
      unity_webapps_music_player_on_next_callback (context, on_next);

      g_main_loop_run (g_main_loop_new (NULL, FALSE));
      
      exit(0);
      }
  g_test_trap_assert_passed();
}

static void
test_music_player_properties ()
{
  //  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;
      gboolean t;
      
      g_thread_init (NULL);

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_music_player_init (context, "Test player");

      unity_webapps_music_player_set_can_go_next (context, TRUE);
      g_assert (unity_webapps_music_player_get_can_go_next (context) == TRUE);
      unity_webapps_music_player_set_can_go_next (context, FALSE);
      g_assert (unity_webapps_music_player_get_can_go_next (context) == FALSE);

      unity_webapps_music_player_set_can_go_previous (context, TRUE);
      g_assert (unity_webapps_music_player_get_can_go_previous (context) == TRUE);
      unity_webapps_music_player_set_can_go_previous (context, FALSE);
      g_assert (unity_webapps_music_player_get_can_go_previous (context) == FALSE);

      unity_webapps_music_player_set_can_play (context, TRUE);
      g_assert (unity_webapps_music_player_get_can_play (context) == TRUE);
      unity_webapps_music_player_set_can_play (context, FALSE);
      g_assert (unity_webapps_music_player_get_can_play (context) == FALSE);

      unity_webapps_music_player_set_can_pause (context, TRUE);
      g_assert (unity_webapps_music_player_get_can_pause (context) == TRUE);
      unity_webapps_music_player_set_can_pause (context, FALSE);
      g_assert (unity_webapps_music_player_get_can_pause (context) == FALSE);
      
      }
  g_test_trap_assert_passed();
}

int 
main (int argc, char **argv)
{
  g_type_init ();
  g_thread_init (NULL);

  g_test_init (&argc, &argv, NULL);


  
  g_test_add_func("/music-player/init",
		  test_music_player_init);
    g_test_add_func("/music-player/set-track",
  		  test_music_player_set_track);
    g_test_add_func("/music-player/callbacks",
  		  test_music_player_callbacks);
    g_test_add_func("/music-player/properties",
		    test_music_player_properties);
  
  return g_test_run ();
}

