#include <stdlib.h>

#include "../src/unity-webapps-service.h"
#include "../src/unity-webapps-context.h"

static void
test_notification_simple_show ()
{
  if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_notification_show_notification (context, "Test", "This is a test", NULL);
      g_printf("Sent notification");
      
      exit(0);
          }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Sent notification");
}

static void
test_notification_show_image ()
{
    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_notification_show_notification (context, "Lambda", "Apparently lambda", "http://www.ubuntu.com/sites/www.ubuntu.com/files/active/02_ubuntu/U_homepage/picto-desktop.png");
      g_printf("Sent notification");
      
      exit(0);
          }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Sent notification");
}

static void
test_notification_show_image_invalid ()
{
    if (g_test_trap_fork (0, G_TEST_TRAP_SILENCE_STDOUT | G_TEST_TRAP_SILENCE_STDERR))
      {
      UnityWebappsService *service;
      UnityWebappsContext *context;

      service = unity_webapps_init ();
      
      context = unity_webapps_context_new (service, "Test", "test.ts");
      
      unity_webapps_notification_show_notification (context, "Lambda", "Apparently lambda", "http://www.ubuntu.com/thisisnotapicture.jpg");
      g_printf("Sent notification");
      
      exit(0);
          }
  g_test_trap_assert_passed();
  g_test_trap_assert_stdout ("Sent notification");
}

int 
main (int argc, char **argv)
{
  g_thread_init(NULL);
  
  g_type_init ();
  g_test_init (&argc, &argv, NULL);
  
  g_test_add_func("/notification/simple-show",
		  test_notification_simple_show);
  g_test_add_func("/notification/show-image",
		  test_notification_show_image);
  g_test_add_func("/notification/show-image-invalid",
		  test_notification_show_image_invalid);
  
  return g_test_run ();
}

